@@ -1,6 +1,6 @@
 import re
 
-from django.utils.six.moves.urllib.parse import quote, urljoin
+from urllib.parse import quote, urljoin
 from django import template
 from django.templatetags.static import StaticNode, PrefixNode
 from django.apps import apps
@@ -16,21 +16,21 @@ class StaticTranspileNode(StaticNode):
     def handle_simple(cls, path):
         path = re.sub(
             r'^js/(.*)\.mjs',
-            r'js/transpile/\1.js',
+            r'js/\1.js',
             path
         )
         if apps.is_installed('django.contrib.staticfiles'):
             from django.contrib.staticfiles.storage import staticfiles_storage
             return (
                 staticfiles_storage.url(path) +
-                '?v=%s' % LAST_RUN['version']
+                '?v=%s' % LAST_RUN['transpile']
             )
         else:
             return (
                 urljoin(
                     PrefixNode.handle_simple("STATIC_URL"),
                     quote(path)
-                ) + '?v=%s' % LAST_RUN['version']
+                ) + '?v=%s' % LAST_RUN['transpile']
             )
 
 
@@ -42,7 +42,7 @@ def static(parser, token):
     Usage::
         {% static path [as varname] %}
     Examples::
-        {% static "js/index.mjs" %} # turns into js/transpile/index.js?v=213...
+        {% static "js/index.mjs" %} # turns into js/index.js?v=213...
         {% static "css/style.css" %} # turns into css/style.css?v=213...
         {% static variable_with_path %}
         {% static variable_with_path as varname %}
